@@ -6,7 +6,7 @@ use vars qw($VERSION);
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '0.22';
+$VERSION = '1.00';
 
 use constant DEFAULT_STATE => 'VIC';
 
@@ -46,7 +46,7 @@ Date::Holidays::Adapter::AU - an adapter class for Date::Holidays::AU
 
 =head1 VERSION
 
-This POD describes version 0.22 of Date::Holidays::Adapter::AU
+This POD describes version 1.00 of Date::Holidays::Adapter::AU
 
 =head1 DESCRIPTION
 
@@ -78,36 +78,7 @@ concatenated.
 
 =head1 DIAGNOSTICS
 
-=over
-
-=item * L<Date::Holidays::Exception::AdapterLoad>
-
-This exception is thrown when L<Date::Holidays::Adapter> attempts to load an
-actual adapter implementation. This exception is recoverable to the extend
-that is caught and handled internally.
-
-When caught the SUPER adapter is attempted loaded, L<Date::Holidays::Adapter>
-if this however fails L<Date::Holidays::Exception::SuperAdapterLoad> it thrown
-see below.
-
-=item * L<Date::Holidays::Exception::AdapterInitialization>
-
-This exception is thrown when in was not possible to load either a
-implementation of a given adapter, or the SUPER adapter
-L<Date::Holidays::Adapter>.
-
-=item * L<Date::Holidays::Exception::NoCountrySpecified>
-
-The exception is thrown if a country code is provided, which is not listed
-in L<Locale::Country>, which lists ISO 3166 codes, which is the unique 2
-character strings assigned to each country in the world.
-
-=item * L<Date::Holidays::Exception::UnsupportedMethod>
-
-Exception thrown in the case where the loaded and initialized module does not
-support the called method. (SEE: METHODS/SUBROUTINES).
-
-=back
+Please refer to DIAGNOSTICS in L<Date::Holidays>
 
 =head1 DEPENDENCIES
 
@@ -117,16 +88,6 @@ support the called method. (SEE: METHODS/SUBROUTINES).
 
 =item * L<Date::Holidays::Adapter>
 
-=item * L<Date::Holidays::Exception::UnsupportedMethod>
-
-=item * L<Date::Holidays::Exception::InvalidCountryCode>
-
-=item * L<Date::Holidays::Exception::NoCountrySpecified>
-
-=item * L<Date::Holidays::Exception::UnsupportedMethod>
-
-=item * L<Error>
-
 =back
 
 =head1 INCOMPATIBILITIES
@@ -158,10 +119,6 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 L<Date::Holidays> and related modules are (C) by Jonas B. Nielsen, (jonasbn)
 2004-2014
 
-L<Date::Holidays> and related modules are released under the artistic license
-
-The distribution is licensed under the Artistic License, as specified
-by the Artistic file in the standard perl distribution
-(http://www.perl.com/language/misc/Artistic.html).
+Date-Holidays and related modules are released under the Artistic License 2.0
 
 =cut
